==> tuia-explore-center-api-1.0.2-20190822.093908-1-sources.jar: cn/tuia/explore/center/api/dto/req/RequestDto.java <==
package cn.tuia.explore.center.api.dto.req;

import cn.tuia.explore.center.api.enums.PostChannel;
import cn.tuia.explore.center.api.enums.PostFlowFetchType;

import java.io.Serializable;

/**
 * 请求相关参数
 *
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: RequestDto.java , v 0.1 2018-08-27 下午5:52 ElinZhou Exp $
 */
public class RequestDto implements Serializable {
    private static final long serialVersionUID = -6706922722045494146L;

    /**
     * 当前请求IP
     */
    private String ip;


    /**
     * 当前请求的版本号
     */
    private String version;

    /**
     * 请求渠道号
     */
    private String source;

    /**
     * 加载内容
     */
    private PostFlowFetchType type;

    /**
     * 加载频道
     */
    private PostChannel postChannel;

    /**
     * 是否可重复（与之前已读内容）
     */
    private boolean canDuplicate;

    /**
     * 请求内容数量
     */
    private int count;


    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public PostFlowFetchType getType() {
        return type;
    }

    public void setType(PostFlowFetchType type) {
        this.type = type;
    }

    public PostChannel getPostChannel() {
        return postChannel;
    }

    public void setPostChannel(PostChannel postChannel) {
        this.postChannel = postChannel;
    }

    public boolean isCanDuplicate() {
        return canDuplicate;
    }

    public void setCanDuplicate(boolean canDuplicate) {
        this.canDuplicate = canDuplicate;
    }

    public int getCount() {
        return count;
    }

    public void setCount(int count) {
        this.count = count;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }
}

==> tuia-explore-center-api-1.1.2-20191011.025224-2-sources.jar: cn/tuia/explore/center/api/dto/req/RequestDto.java <==
package cn.tuia.explore.center.api.dto.req;

import cn.tuia.explore.center.api.enums.PostChannel;
import cn.tuia.explore.center.api.enums.PostFlowFetchType;

import java.io.Serializable;
import java.util.Collection;

/**
 * 请求相关参数
 *
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: RequestDto.java , v 0.1 2018-08-27 下午5:52 ElinZhou Exp $
 */
public class RequestDto implements Serializable {
    private static final long serialVersionUID = -6706922722045494146L;

    /**
     * 当前请求IP
     */
    private String ip;


    /**
     * 当前请求的版本号
     */
    private Long version;

    /**
     * 请求渠道号
     */
    private String source;

    /**
     * 加载内容
     */
    private PostFlowFetchType type;

    /**
     * 加载频道
     */
    private PostChannel postChannel;

    /**
     * 是否可重复（与之前已读内容）
     */
    private boolean canDuplicate;

    /**
     * 请求内容数量
     */
    private int count;

    /**
     * 请求的标签
     */
    private Collection<Integer> tags;


    public Long getVersion() {
        return version;
    }

    public void setVersion(Long version) {
        this.version = version;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public PostFlowFetchType getType() {
        return type;
    }

    public void setType(PostFlowFetchType type) {
        this.type = type;
    }

    public PostChannel getPostChannel() {
        return postChannel;
    }

    public void setPostChannel(PostChannel postChannel) {
        this.postChannel = postChannel;
    }

    public boolean isCanDuplicate() {
        return canDuplicate;
    }

    public void setCanDuplicate(boolean canDuplicate) {
        this.canDuplicate = canDuplicate;
    }

    public int getCount() {
        return count;
    }

    public void setCount(int count) {
        this.count = count;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public Collection<Integer> getTags() {
        return tags;
    }

    public void setTags(Collection<Integer> tags) {
        this.tags = tags;
    }
}
